pub struct ConfigSkin {
pub id: SkinId,
pub name: I18nString,
pub unlock_description: Option<I18nString>,
pub code: String,
pub skin_type: SkinType,
pub icon_url: String,
pub icon_path: String,
pub spine_path: String,
pub rarity_id: ItemRarityId,
pub price: Option<Vec<CurrencyUnit>>,
pub color: Option<String>,
}Fields
id: SkinIdname: I18nStringunlock_description: Option<I18nString>code: Stringskin_type: SkinTypeicon_url: Stringicon_path: Stringspine_path: Stringrarity_id: ItemRarityIdprice: Option<Vec<CurrencyUnit>>color: Option<String>Trait Implementations
Sourceimpl Clone for ConfigSkin
impl Clone for ConfigSkin
Sourcefn clone(&self) -> ConfigSkin
fn clone(&self) -> ConfigSkin
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for ConfigSkin
impl CustomType for ConfigSkin
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for ConfigSkin
impl Debug for ConfigSkin
Sourceimpl Default for ConfigSkin
impl Default for ConfigSkin
Sourcefn default() -> ConfigSkin
fn default() -> ConfigSkin
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ConfigSkin
impl<'de> Deserialize<'de> for ConfigSkin
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ConfigSkin
impl Hash for ConfigSkin
Sourceimpl JsonSchema for ConfigSkin
impl JsonSchema for ConfigSkin
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConfigSkin
impl PartialEq for ConfigSkin
Sourceimpl Serialize for ConfigSkin
impl Serialize for ConfigSkin
Sourceimpl Tsify for ConfigSkin
impl Tsify for ConfigSkin
const DECL: &'static str = "export interface ConfigSkin {\n id: SkinId;\n name: I18nString;\n unlock_description: I18nString | null;\n code: string;\n skin_type: SkinType;\n icon_url: string;\n icon_path: string;\n spine_path: string;\n rarity_id: ItemRarityId;\n price: CurrencyUnit[] | null;\n color: string | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ConfigSkin
impl StructuralPartialEq for ConfigSkin