pub struct SkinsSettings {
pub default_unlocked_skins: Vec<SkinId>,
pub default_equipped_skins: Vec<SkinId>,
}Fields
default_unlocked_skins: Vec<SkinId>default_equipped_skins: Vec<SkinId>Trait Implementations
Sourceimpl Clone for SkinsSettings
impl Clone for SkinsSettings
Sourcefn clone(&self) -> SkinsSettings
fn clone(&self) -> SkinsSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for SkinsSettings
impl CustomType for SkinsSettings
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for SkinsSettings
impl Debug for SkinsSettings
Sourceimpl Default for SkinsSettings
impl Default for SkinsSettings
Sourcefn default() -> SkinsSettings
fn default() -> SkinsSettings
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SkinsSettings
impl<'de> Deserialize<'de> for SkinsSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SkinsSettings
impl JsonSchema for SkinsSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SkinsSettings
impl PartialEq for SkinsSettings
Sourceimpl Serialize for SkinsSettings
impl Serialize for SkinsSettings
Sourceimpl Tsify for SkinsSettings
impl Tsify for SkinsSettings
const DECL: &'static str = "export interface SkinsSettings {\n default_unlocked_skins: SkinId[];\n default_equipped_skins: SkinId[];\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for SkinsSettings
impl StructuralPartialEq for SkinsSettings